==> aws-cdk-scala_3-0.6.0-sources.jar: io/burkard/cdk/services/pinpoint/CfnCampaignProps.scala <==
package io.burkard.cdk.services.pinpoint

import scala.collection.JavaConverters._

@scala.annotation.nowarn("cat=deprecation")
@SuppressWarnings(Array("org.wartremover.warts.DefaultArguments", "org.wartremover.warts.Null", "DisableSyntax.null"))
object CfnCampaignProps {

  def apply(
    name: String,
    applicationId: String,
    segmentId: String,
    messageConfiguration: software.amazon.awscdk.services.pinpoint.CfnCampaign.MessageConfigurationProperty,
    schedule: software.amazon.awscdk.services.pinpoint.CfnCampaign.ScheduleProperty,
    holdoutPercent: Option[Number] = None,
    treatmentDescription: Option[String] = None,
    priority: Option[Number] = None,
    segmentVersion: Option[Number] = None,
    description: Option[String] = None,
    tags: Option[AnyRef] = None,
    treatmentName: Option[String] = None,
    additionalTreatments: Option[List[_]] = None,
    campaignHook: Option[software.amazon.awscdk.services.pinpoint.CfnCampaign.CampaignHookProperty] = None,
    limits: Option[software.amazon.awscdk.services.pinpoint.CfnCampaign.LimitsProperty] = None,
    isPaused: Option[Boolean] = None
  ): software.amazon.awscdk.services.pinpoint.CfnCampaignProps =
    (new software.amazon.awscdk.services.pinpoint.CfnCampaignProps.Builder)
      .name(name)
      .applicationId(applicationId)
      .segmentId(segmentId)
      .messageConfiguration(messageConfiguration)
      .schedule(schedule)
      .holdoutPercent(holdoutPercent.orNull)
      .treatmentDescription(treatmentDescription.orNull)
      .priority(priority.orNull)
      .segmentVersion(segmentVersion.orNull)
      .description(description.orNull)
      .tags(tags.orNull)
      .treatmentName(treatmentName.orNull)
      .additionalTreatments(additionalTreatments.map(_.asJava).orNull)
      .campaignHook(campaignHook.orNull)
      .limits(limits.orNull)
      .isPaused(isPaused.map(Boolean.box).getOrElse(java.lang.Boolean.FALSE))
      .build()
}

==> aws-cdk-scala_3-0.13.1-sources.jar: io/burkard/cdk/services/pinpoint/CfnCampaignProps.scala <==
package io.burkard.cdk.services.pinpoint

import scala.collection.JavaConverters._

@scala.annotation.nowarn("cat=deprecation")
@SuppressWarnings(Array("org.wartremover.warts.DefaultArguments", "org.wartremover.warts.Null", "DisableSyntax.null"))
object CfnCampaignProps {

  def apply(
    name: String,
    applicationId: String,
    segmentId: String,
    messageConfiguration: software.amazon.awscdk.services.pinpoint.CfnCampaign.MessageConfigurationProperty,
    schedule: software.amazon.awscdk.services.pinpoint.CfnCampaign.ScheduleProperty,
    holdoutPercent: Option[Number] = None,
    treatmentDescription: Option[String] = None,
    priority: Option[Number] = None,
    segmentVersion: Option[Number] = None,
    description: Option[String] = None,
    tags: Option[AnyRef] = None,
    treatmentName: Option[String] = None,
    additionalTreatments: Option[List[_]] = None,
    campaignHook: Option[software.amazon.awscdk.services.pinpoint.CfnCampaign.CampaignHookProperty] = None,
    limits: Option[software.amazon.awscdk.services.pinpoint.CfnCampaign.LimitsProperty] = None,
    isPaused: Option[Boolean] = None
  ): software.amazon.awscdk.services.pinpoint.CfnCampaignProps =
    (new software.amazon.awscdk.services.pinpoint.CfnCampaignProps.Builder)
      .name(name)
      .applicationId(applicationId)
      .segmentId(segmentId)
      .messageConfiguration(messageConfiguration)
      .schedule(schedule)
      .holdoutPercent(holdoutPercent.orNull)
      .treatmentDescription(treatmentDescription.orNull)
      .priority(priority.orNull)
      .segmentVersion(segmentVersion.orNull)
      .description(description.orNull)
      .tags(tags.orNull)
      .treatmentName(treatmentName.orNull)
      .additionalTreatments(additionalTreatments.map(_.asJava).orNull)
      .campaignHook(campaignHook.orNull)
      .limits(limits.orNull)
      .isPaused(isPaused.map(Boolean.box).orNull)
      .build()
}
